function love.load()
	love.window.setMode(800, 600, {vsync=false,resizable = true})
	curves = {}
	state = 1
	for i=1,9 do
		curves[i] = {}
	end
	curves[0] = {}
end

function love.update(dt)
	if active then
		if not on then
			curves[state][#curves[state]][1],curves[state][#curves[state]][2] = love.mouse.getPosition()
		else
		    curves[state][on][1],curves[state][on][2] = love.mouse.getPosition()
		end
		if #curves[state] >= 2 then
			local ver = {}
			for i,v in ipairs(curves[state]) do
				ver[#ver+1] = v[1]
				ver[#ver+1] = v[2]
			end
			curves[state]['curve'] = love.math.newBezierCurve(ver)
		else
		    curves[state]['curve'] = nil
		end
	end
	if edit then
		curves[state]['curve']:scale(1.2,curves[state]['cp'][1],curves[state]['cp'][2]) --dist(curves[state]['cp'][1],curves[state]['cp'][2],love.mouse.getX(),love.mouse.getY())
		edit = false
	end
end

function love.draw()
	--draw curves
	for i,v in ipairs(curves) do
		if v['curve'] then
			if i == state then
				love.graphics.setColor(255,255,255)
			else
			    love.graphics.setColor(255,255,255,0)
			end
			love.graphics.line(v['curve']:render(0))
			love.graphics.setColor(255,0,0,255)
			love.graphics.line(v['curve']:render())
		end
	end
	
	--draws points
	for i,v in ipairs(curves[state]) do
		if dist(love.mouse.getX(),love.mouse.getY(),v[1],v[2]) <= 5 then
			love.graphics.setColor(0,0,255)
		else
		    love.graphics.setColor(139,208,186)
		end
		love.graphics.circle('line', v[1], v[2], 5, 32)
		love.graphics.setColor(255,255,255)
		love.graphics.point(v[1], v[2])
	end

	--gets center point
	local x = 0
	local y = 0
	for i,v in ipairs(curves[state]) do
		x = x + v[1]
		y = y + v[2]
	end
	x=x/#curves[state]
	y=y/#curves[state]
	curves[state]['cp'] = {x,y}
	love.graphics.circle('line', x, y, 5, 32)

	love.graphics.setColor(255,255,255,255)
	love.graphics.print('State: '..state,0,0)

	love.window.setTitle(love.timer.getFPS())
end

function love.mousepressed(x, y, button)
	if button == 'l' then
		for i,v in ipairs(curves[state]) do
			if dist(x,y,v[1],v[2]) <= 5 then
				on = i
				active = true
				return
			end
		end
		if dist(x,y,curves[state]['cp'][1],curves[state]['cp'][2]) <= 5 then
			edit = true
			return
		end
		curves[state][#curves[state]+1] = {x,y}
		active = true
	elseif button == 'r' then
		for i,v in ipairs(curves[state]) do
			if dist(x,y,v[1],v[2]) <= 5 then
				table.remove(curves[state], i)
				return
			end
		end
	end
	if #curves[state] >= 2 then
		local ver = {}
		for i,v in ipairs(curves[state]) do
			ver[#ver+1] = v[1]
			ver[#ver+1] = v[2]
		end
		curves[state]['curve'] = love.math.newBezierCurve(ver)
	else
	    curves[state]['curve'] = nil
	end
end

function love.mousereleased(x, y, button)
	if button == 'l' then
		active = false
		edit = false
		on = nil
	end
	if #curves[state] >= 2 then
		local ver = {}
		for i,v in ipairs(curves[state]) do
			ver[#ver+1] = v[1]
			ver[#ver+1] = v[2]
		end
		curves[state]['curve'] = love.math.newBezierCurve(ver)
	else
	    curves[state]['curve'] = nil
	end
end

function love.keypressed(k)
	if tonumber(k) ~= nil then
		state = tonumber(k)
	end
end

function love.keyreleased(k)
	if k == 'delete' then
		if not love.keyboard.isDown('lctrl') then
			curves[state] = {}
		else
		    for i=1,9 do
				curves[i] = {}
			end
			curves[0] = {}
		end
	end
end

function dist(x1,y1,x2,y2)
	return math.sqrt(math.pow(x1-x2, 2)+math.pow(y1-y2, 2))
end
